"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.formatCodeSync = exports.formatCode = exports.getPrettierConfig = void 0;
const prettier_1 = __importDefault(require("prettier"));
const format_shared_1 = require("./format.shared");
const utils_1 = require("./utils");
async function getPrettierConfig(path) {
    try {
        const prettierConfig = await prettier_1.default.resolveConfig(path, {
            editorconfig: true,
            useCache: true,
        });
        return prettierConfig || format_shared_1.defaultPrettierConfig;
    }
    catch (e) {
        return format_shared_1.defaultPrettierConfig;
    }
}
exports.getPrettierConfig = getPrettierConfig;
function getPrettierConfigSync(path) {
    try {
        const prettierConfig = prettier_1.default.resolveConfig.sync(path, {
            editorconfig: true,
            useCache: true,
        });
        return prettierConfig || format_shared_1.defaultPrettierConfig;
    }
    catch (e) {
        return format_shared_1.defaultPrettierConfig;
    }
}
const formatCode = async ({ path, contents: c }) => {
    let fileContents = (0, utils_1.contentsToString)(c);
    const [{ inferredParser }, prettierOptions] = await Promise.all([
        prettier_1.default.getFileInfo(path, {
            resolveConfig: false,
        }),
        getPrettierConfig(path),
    ]);
    if (inferredParser) {
        try {
            fileContents = prettier_1.default.format(fileContents, {
                ...prettierOptions,
                parser: inferredParser,
            });
        }
        catch (error) {
            console.log(error.codeFrame);
            throw error;
        }
    }
    return fileContents;
};
exports.formatCode = formatCode;
const formatCodeSync = ({ path, contents: c }) => {
    let fileContents = (0, utils_1.contentsToString)(c);
    const { inferredParser } = prettier_1.default.getFileInfo.sync(path, {
        resolveConfig: false,
    });
    const prettierOptions = getPrettierConfigSync(path);
    if (inferredParser) {
        try {
            fileContents = prettier_1.default.format(fileContents, {
                ...prettierOptions,
                parser: inferredParser,
            });
        }
        catch (error) {
            console.log(error.codeFrame);
            throw error;
        }
    }
    return fileContents;
};
exports.formatCodeSync = formatCodeSync;
//# sourceMappingURL=format-node.js.map