"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var _a;
Object.defineProperty(exports, "__esModule", { value: true });
const ava_1 = __importDefault(require("ava"));
const node_path_1 = require("node:path");
const node_os_1 = require("node:os");
const file_utils_1 = require("./file-utils");
const resolve_1 = require("./resolve");
const appUiDir = (0, node_path_1.join)(__dirname, '../../../apps/ui/app-ui');
if (((_a = (0, file_utils_1.readJSONSync)((0, node_path_1.join)(appUiDir, 'package.json'))) === null || _a === void 0 ? void 0 : _a.name) !== '@knapsack/app-ui') {
    throw new Error(`The 'appUiDir' path is not correct. Expected to be in the root of the app-ui package.`);
}
const fixturesFolder = (0, node_path_1.join)(__dirname, '../test-fixtures');
(0, file_utils_1.assertDirExists)(fixturesFolder);
/**
 * Resolvers are used to test both the async and sync versions of resolvePath.
 * This works since it's ok to `await` a sync function and they have same return type.
 */
const resolvers = [resolve_1.resolvePath, resolve_1.resolvePathSync];
(0, ava_1.default)('getPathType', async (t) => {
    t.deepEqual((0, resolve_1.getPathType)('@knapsack/file-utils'), {
        type: 'package',
    });
    t.deepEqual((0, resolve_1.getPathType)('ava'), {
        type: 'package',
    });
    t.deepEqual((0, resolve_1.getPathType)('ava/package.json'), {
        type: 'package-sub-path',
        subPath: './package.json',
        pkgName: 'ava',
    });
    t.deepEqual((0, resolve_1.getPathType)('ava/sub/item'), {
        type: 'package-sub-path',
        subPath: './sub/item',
        pkgName: 'ava',
    });
    t.deepEqual((0, resolve_1.getPathType)('@org/ava/package.json'), {
        type: 'package-sub-path',
        subPath: './package.json',
        pkgName: '@org/ava',
    });
    t.deepEqual((0, resolve_1.getPathType)('@org/ava/sub/item'), {
        type: 'package-sub-path',
        subPath: './sub/item',
        pkgName: '@org/ava',
    });
    t.deepEqual((0, resolve_1.getPathType)('./ava'), {
        type: 'relative',
    });
    t.deepEqual((0, resolve_1.getPathType)('../ava'), {
        type: 'relative',
    });
});
(0, ava_1.default)('resolvePath: absolute', async (t) => {
    for (const resolver of resolvers) {
        const path = (0, node_path_1.join)(__dirname, '../tsconfig.json');
        const { exists, type } = await resolver({
            path,
        });
        t.is(type, 'absolute');
        t.true(exists);
    }
});
(0, ava_1.default)('resolvePath: package sub-path', async (t) => {
    for (const resolver of resolvers) {
        const { exists, type, absolutePath } = await resolver({
            path: '@knapsack/file-utils/package.json',
        });
        t.is(type, 'package');
        t.is(absolutePath, (0, node_path_1.join)(__dirname, '../package.json'));
        t.true(exists);
    }
});
(0, ava_1.default)('resolvePath: relative', async (t) => {
    for (const resolver of resolvers) {
        const { exists, absolutePath, type } = await resolver({
            path: './tsconfig.json',
        });
        t.is(absolutePath, (0, node_path_1.join)(__dirname, '../tsconfig.json'));
        t.is(type, 'relative');
        t.true(exists);
    }
});
(0, ava_1.default)('resolvePath: regular CJS export', async (t) => {
    for (const resolver of resolvers) {
        const result = await resolver({
            path: '@knapsack/app',
            resolveFromDir: appUiDir,
            resolveType: 'cjs',
        });
        t.true(result.exists);
        t.is(result.type, 'package');
        t.true(result.absolutePath.endsWith('dist/index.js'), `Expected to end with 'dist/index.js': ${result.absolutePath}`);
    }
});
(0, ava_1.default)('resolvePath: sub-path exports mjs', async (t) => {
    for (const resolver of resolvers) {
        const result = await resolver({
            path: '@knapsack/toby/global-styles',
            resolveFromDir: appUiDir,
        });
        t.true(result.exists);
        t.is(result.type, 'package');
        t.true(result.absolutePath.endsWith('dist/global-styles/index.js'), `Expected to end with 'dist/global-styles/index.js': ${result.absolutePath}`);
    }
});
(0, ava_1.default)('resolvePath: sub-path exports types', async (t) => {
    for (const resolver of resolvers) {
        const result = await resolver({
            path: '@knapsack/toby/global-styles',
            resolveFromDir: appUiDir,
            resolveType: 'types',
        });
        t.true(result.exists);
        t.is(result.type, 'package');
        t.true(result.absolutePath.endsWith('dist/global-styles/index.d.ts'), `Expected to end with 'dist/global-styles/index.d.ts': ${result.absolutePath}`);
    }
});
(0, ava_1.default)('resolvePath: mjs w/just export', async (t) => {
    for (const resolver of resolvers) {
        const result = await resolver({
            path: '@knapsack/hooks',
            resolveFromDir: appUiDir,
            resolveType: 'mjs',
        });
        t.is(result.type, 'package');
        t.true(result.exists);
        t.true(result.absolutePath.endsWith('dist/index.js'), `Expected to end with 'dist/index.js': ${result.absolutePath}`);
    }
});
(0, ava_1.default)('resolvePath: types w/just exports', async (t) => {
    for (const resolver of resolvers) {
        const result = await resolver({
            path: '@knapsack/css-vars',
            resolveFromDir: appUiDir,
            resolveType: 'types',
        });
        t.is(result.type, 'package');
        t.true(result.exists);
        t.true(result.absolutePath.endsWith('dist/index.d.ts'), `Expected to end with 'dist/index.d.ts': ${result.absolutePath}`);
    }
});
(0, ava_1.default)('resolvePath: exports from dual module pkg', async (t) => {
    for (const resolver of resolvers) {
        const mjsResult = await resolver({
            path: '@knapsack/utils',
            resolveFromDir: appUiDir,
            resolveType: 'mjs',
        });
        t.is(mjsResult.type, 'package');
        t.true(mjsResult.exists);
        t.true(mjsResult.absolutePath.endsWith('dist/index.mjs'), `Expected to end with 'dist/index.mjs': ${mjsResult.absolutePath}`);
        const cjsResult = await resolver({
            path: '@knapsack/utils',
            resolveFromDir: appUiDir,
            resolveType: 'cjs',
        });
        t.is(cjsResult.type, 'package');
        t.true(cjsResult.exists);
        t.true(cjsResult.absolutePath.endsWith('dist/index.js'), `Expected to end with 'dist/index.js': ${cjsResult.absolutePath}`);
        const typesResult = await resolver({
            path: '@knapsack/utils',
            resolveFromDir: appUiDir,
            resolveType: 'types',
        });
        t.is(typesResult.type, 'package');
        t.true(typesResult.exists);
        t.true(typesResult.absolutePath.endsWith('dist/index.d.ts'), `Expected to end with 'dist/index.d.ts': ${typesResult.absolutePath}`);
    }
});
(0, ava_1.default)('resolvePath: relative with resolve from dir', async (t) => {
    for (const resolver of resolvers) {
        const { exists, absolutePath, type } = await resolver({
            path: '../tsconfig.json',
            resolveFromDir: __dirname,
        });
        t.is(absolutePath, (0, node_path_1.join)(__dirname, '../tsconfig.json'));
        t.is(type, 'relative');
        t.true(exists);
    }
});
(0, ava_1.default)('resolve: non-existant files', async (t) => {
    for (const resolver of resolvers) {
        const typesResult = await resolver({
            path: './missing-files',
            resolveFromDir: fixturesFolder,
            resolveType: 'types',
        });
        t.false(typesResult.exists);
        const jsResult = await resolver({
            path: './missing-files',
            resolveFromDir: fixturesFolder,
        });
        t.false(jsResult.exists);
    }
});
(0, ava_1.default)('resolve: legacy cjs', async (t) => {
    for (const resolver of resolvers) {
        const result = await resolver({
            path: './legacy-cjs',
            resolveFromDir: fixturesFolder,
        });
        t.true(result.exists);
        t.is(result.absolutePath, (0, node_path_1.join)(fixturesFolder, 'legacy-cjs/index.js'));
    }
});
(0, ava_1.default)('resolve: legacy cjs-main', async (t) => {
    for (const resolver of resolvers) {
        const result = await resolver({
            path: (0, node_path_1.join)(fixturesFolder, './legacy-cjs-main'),
        });
        t.true(result.exists);
        t.is(result.absolutePath, (0, node_path_1.join)(fixturesFolder, 'legacy-cjs-main/main.js'));
    }
});
(0, ava_1.default)('resolve: legacy mjs-module', async (t) => {
    for (const resolver of resolvers) {
        const result = await resolver({
            path: './legacy-mjs-module',
            resolveFromDir: fixturesFolder,
        });
        t.true(result.exists);
        t.is(result.absolutePath, (0, node_path_1.join)(fixturesFolder, 'legacy-mjs-module/main.mjs'));
    }
});
(0, ava_1.default)('resolve(a): exports with import & require', async (t) => {
    for (const resolver of resolvers) {
        const result = await resolver({
            path: './a',
            resolveFromDir: fixturesFolder,
        });
        t.true(result.exists);
        t.is(result.absolutePath, (0, node_path_1.join)(fixturesFolder, 'a/main.mjs'));
        const cjsResult = await resolver({
            path: './a',
            resolveFromDir: fixturesFolder,
            resolveType: 'cjs',
        });
        t.true(cjsResult.exists);
        t.is(cjsResult.absolutePath, (0, node_path_1.join)(fixturesFolder, 'a/main.js'));
    }
});
(0, ava_1.default)('resolve(b): types from pkg.json', async (t) => {
    for (const resolver of resolvers) {
        const result = await resolver({
            path: './b',
            resolveFromDir: fixturesFolder,
            resolveType: 'types',
        });
        t.true(result.exists);
        t.is(result.absolutePath, (0, node_path_1.join)(fixturesFolder, 'b/main.d.ts'));
    }
});
(0, ava_1.default)('resolve(c): types w/no help from pkg.json', async (t) => {
    for (const resolver of resolvers) {
        const jsResult = await resolver({
            path: './c',
            resolveFromDir: fixturesFolder,
        });
        t.is(jsResult.absolutePath, (0, node_path_1.join)(fixturesFolder, 'c/main.js'));
        t.true(jsResult.exists);
        const result = await resolver({
            path: './c',
            resolveFromDir: fixturesFolder,
            resolveType: 'types',
        });
        t.is(result.absolutePath, (0, node_path_1.join)(fixturesFolder, 'c/main.d.ts'));
        t.true(result.exists);
    }
});
(0, ava_1.default)('convertJsExtensionToDts', (t) => {
    t.is((0, resolve_1.convertJsExtensionToDts)('.js'), '.d.ts');
    t.is((0, resolve_1.convertJsExtensionToDts)('.mjs'), '.d.mts');
    t.is((0, resolve_1.convertJsExtensionToDts)('.cjs'), '.d.cts');
    t.is((0, resolve_1.convertJsExtensionToDts)('.cts'), '.d.cts');
    t.is((0, resolve_1.convertJsExtensionToDts)('.mjsx'), '.d.mts');
    t.is((0, resolve_1.convertJsExtensionToDts)('.cjsx'), '.d.cts');
    t.is((0, resolve_1.convertJsExtensionToDts)('.json'), '.d.ts');
});
(0, ava_1.default)('resolvePkgExport: types', (t) => {
    {
        const result = (0, resolve_1.resolvePkgExport)({
            pkg: {
                exports: {
                    '.': {
                        default: './main.js',
                    },
                },
            },
            resolveType: 'types',
            subPath: '.',
        });
        t.falsy(result);
    }
    {
        const result = (0, resolve_1.resolvePkgExport)({
            pkg: {
                exports: {
                    '.': {
                        types: './main.d.ts',
                        default: './main.js',
                    },
                },
            },
            resolveType: 'types',
            subPath: '.',
        });
        t.is(result, './main.d.ts');
    }
    {
        const result = (0, resolve_1.resolvePkgExport)({
            pkg: {
                types: './main.d.ts',
                exports: {
                    '.': {
                        default: './main.js',
                    },
                },
            },
            resolveType: 'types',
            subPath: '.',
        });
        t.is(result, './main.d.ts');
    }
    {
        const result = (0, resolve_1.resolvePkgExport)({
            pkg: {
                typings: './main.d.ts',
                exports: {
                    '.': {
                        default: './main.js',
                    },
                },
            },
            resolveType: 'types',
            subPath: '.',
        });
        t.is(result, './main.d.ts');
    }
});
(0, ava_1.default)('caches should not cache fails', async (t) => {
    for (const resolver of resolvers) {
        const file = (0, node_path_1.join)((0, node_os_1.tmpdir)(), `some-file-${Math.random()}.js`);
        const result = await resolver({
            path: file,
        });
        t.false(result.exists);
        await (0, file_utils_1.writeFile)({
            path: file,
            contents: '',
        });
        const result2 = await resolver({
            path: file,
        });
        t.true(result2.exists);
        await (0, file_utils_1.remove)(file);
    }
});
//# sourceMappingURL=resolve.test.js.map